package com.fastbee.rechargecard.service;

import java.util.List;
import com.fastbee.rechargecard.domain.UserIrrigationRecord;
import com.fastbee.rechargecard.domain.dto.UserIrrigationRecordDto;

/**
 * 灌溉记录Service接口
 *
 * @author kerwincui
 * @date 2024-12-18
 */
public interface IUserIrrigationRecordService
{
    /**
     * 查询用户灌溉展示记录列表
     *
     * @param cardNumber 卡号
     * @return 灌溉记录
     */
    public List<UserIrrigationRecordDto> selectUserIrrigationRecordListShowBycardNumber(String cardNumber);

    /**
     * 查询用户灌溉记录列表
     *
     * @param cardNumber 卡号
     * @return 灌溉记录
     */
    public List<UserIrrigationRecord> selectUserIrrigationRecordListBycardNumber(String cardNumber);

    /**
     * 查询灌溉记录
     *
     * @param id 灌溉记录主键
     * @return 灌溉记录
     */
    public UserIrrigationRecord selectUserIrrigationRecordById(Long id);

    /**
     * 查询灌溉记录列表
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 灌溉记录集合
     */
    public List<UserIrrigationRecord> selectUserIrrigationRecordList(UserIrrigationRecord userIrrigationRecord);

    /**
     * 新增灌溉记录
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 结果
     */
    public int insertUserIrrigationRecord(UserIrrigationRecord userIrrigationRecord);

    /**
     * 修改灌溉记录
     *
     * @param userIrrigationRecord 灌溉记录
     * @return 结果
     */
    public int updateUserIrrigationRecord(UserIrrigationRecord userIrrigationRecord);

    /**
     * 批量删除灌溉记录
     *
     * @param ids 需要删除的灌溉记录主键集合
     * @return 结果
     */
    public int deleteUserIrrigationRecordByIds(Long[] ids);

    /**
     * 删除灌溉记录信息
     *
     * @param id 灌溉记录主键
     * @return 结果
     */
    public int deleteUserIrrigationRecordById(Long id);
}
